# {{cookiecutter.title}}

[![Build Status](https://github.com/{{cookiecutter.github_org}}/{{cookiecutter.github_repo_name}}/actions/workflows/ci.yaml/badge.svg)](https://github.com/{{cookiecutter.github_org}}/{{cookiecutter.github_repo_name}}/actions/workflows/ci.yaml)
[![PyPI Package](https://img.shields.io/pypi/v/{{cookiecutter.pypi_package_name}})](https://pypi.org/project/{{cookiecutter.pypi_package_name}}/)
[![Docs](https://img.shields.io/badge/docs-latest-informational)](https://{{cookiecutter.github_org}}.github.io/{{cookiecutter.github_repo_name}}/)

## Introduction

{{cookiecutter.description}}

TODO(cookiecutter): Improve the README file

## Contributing

If you want to know how to build this project and contribute to it, please
check out the [Contributing Guide](CONTRIBUTING.md).
